# Generated by Django 5.1.4 on 2025-01-20 07:24

import django.db.models.deletion
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0002_poly_polyone_polytwo'),
    ]

    operations = [
        migrations.AlterField(
            model_name='author',
            name='first_name',
            field=models.CharField(max_length=100, verbose_name='Vorname'),
        ),
        migrations.CreateModel(
            name='Detail',
            fields=[
                ('order', models.PositiveIntegerField(db_index=True, editable=False, verbose_name='order')),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('integer', models.IntegerField(verbose_name='An integer field')),
                ('number', models.FloatField(verbose_name='A float field')),
                ('char', models.CharField(max_length=100, verbose_name='Text field')),
                ('text', models.TextField(verbose_name='Multiline Text')),
                ('boolean', models.BooleanField(default=None, null=True, verbose_name='A boolean value')),
                ('boolean_two', models.BooleanField(default=None, null=True, verbose_name='Another boolean value')),
                ('date', models.DateField(verbose_name='A date field')),
                ('date_time', models.DateTimeField(verbose_name='A date field with time')),
                ('created_dt', models.DateTimeField(auto_now_add=True)),
                ('modified_dt', models.DateTimeField(auto_now=True)),
                ('author', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.author', verbose_name='A foreign key field')),
                ('foo', models.ManyToManyField(to='app.foo', verbose_name='Foo selected')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
        ),
    ]
